@@ -47,6 +47,7 @@ KEYWORD_NAMES = ['TTYPE', 'TFORM', 'TUNIT', 'TNULL', 'TSCAL', 'TZERO',
                  'TDISP', 'TBCOL', 'TDIM']
 KEYWORD_ATTRIBUTES = ['name', 'format', 'unit', 'null', 'bscale', 'bzero',
                       'disp', 'start', 'dim']
+"""This is a list of the attributes that can be set on `Column` objects."""
 
 # TFORM regular expression
 TFORMAT_RE = re.compile(r'(?P<repeat>^[0-9]*)(?P<dtype>[A-Za-z])'
@@ -185,9 +186,8 @@ class _FormatP(str):
 
 class Column(object):
     """
-    Class which contains the definition of one column, e.g.  `ttype`,
-    `tform`, etc. and the array containing values for the column.
-    Does not support `theap` yet.
+    Class which contains the definition of one column, e.g.  ``ttype``,
+    ``tform``, etc. and the array containing values for the column.
     """
 
     def __init__(self, name=None, format=None, unit=None, null=None,
@@ -429,7 +429,7 @@ class ColDefs(object):
         input :
             An existing table HDU, an existing ColDefs, or recarray
 
-        **(Deprecated)** tbtype : str (optional)
+        **(Deprecated)** tbtype : str, optional
             which table HDU, ``"BinTableHDU"`` (default) or
             ``"TableHDU"`` (text table).
             Now ColDefs for a normal (binary) table by default, but converted
@@ -671,8 +671,10 @@ class ColDefs(object):
 
     def change_attrib(self, col_name, attrib, new_value):
         """
-        Change an attribute (in the commonName list) of a `Column`.
+        Change an attribute (in the ``KEYWORD_ATTRIBUTES`` list) of a `Column`.
 
+        Parameters
+        ----------
         col_name : str or int
             The column name or index to change
 
@@ -694,6 +696,8 @@ class ColDefs(object):
         """
         Change a `Column`'s name.
 
+        Parameters
+        ----------
         col_name : str
             The current name of the column
 
@@ -714,6 +718,8 @@ class ColDefs(object):
         """
         Change a `Column`'s unit.
 
+        Parameters
+        ----------
         col_name : str or int
             The column name or index
 
@@ -735,14 +741,14 @@ class ColDefs(object):
         ----------
         attrib : str
             Can be one or more of the attributes listed in
-            `KEYWORD_ATTRIBUTES`.  The default is ``"all"`` which will print
-            out all attributes.  It forgives plurals and blanks.  If
-            there are two or more attribute names, they must be
+            ``pyfits.column.KEYWORD_ATTRIBUTES``.  The default is ``"all"``
+            which will print out all attributes.  It forgives plurals and
+            blanks.  If there are two or more attribute names, they must be
             separated by comma(s).
 
         output : file, optional
             File-like object to output to.  Outputs to stdout by default.
-            If False, returns the attributes as a dict instead.
+            If `False`, returns the attributes as a `dict` instead.
 
         Notes
         -----
