@@ -2316,6 +2316,28 @@ class TestRecordValuedKeywordCards(PyfitsTestCase):
         self._test_header['DP1.AXIS.1'] = 1.1
         assert_equal(self._test_header['DP1.AXIS.1'], 1.1)
 
+    def test_update_rvkc_2(self):
+        """Regression test for an issue that appeared after SVN r2412."""
+
+        h = pyfits.Header()
+        h['D2IM1.EXTVER'] = 1
+        assert h['D2IM1.EXTVER'] == 1.0
+        h['D2IM1.EXTVER'] = 2
+        assert h['D2IM1.EXTVER'] == 2.0
+
+    def test_raw_keyword_value(self):
+        c = pyfits.Card.fromstring("DP1     = 'NAXIS: 2' / A comment")
+        assert c.rawkeyword == 'DP1'
+        assert c.rawvalue == 'NAXIS: 2'
+
+        c = pyfits.Card('DP1.NAXIS', 2)
+        assert c.rawkeyword == 'DP1'
+        assert c.rawvalue == 'NAXIS: 2.0'
+
+        c = pyfits.Card('DP1.NAXIS', 2.0)
+        assert c.rawkeyword == 'DP1'
+        assert c.rawvalue == 'NAXIS: 2.0'
+
     def test_rvkc_insert_after(self):
         """
         It should be possible to insert a new RVKC after an existing one
@@ -2339,6 +2361,15 @@ class TestRecordValuedKeywordCards(PyfitsTestCase):
         assert_equal(self._test_header.keys()[1], 'DP1.AXIS.2')
         assert_equal(self._test_header[1], 2)
 
+        # Perform a subsequent delete to make sure all the index mappings were
+        # updated
+        del self._test_header['DP1.AXIS.2']
+        assert len(self._test_header) == 6
+        assert self._test_header.keys()[0] == 'DP1.NAXIS'
+        assert self._test_header[0] == 2
+        assert self._test_header.keys()[1] == 'DP1.NAUX'
+        assert self._test_header[1] == 2
+
     def test_pattern_matching_keys(self):
         """Test the keyword filter strings with RVKCs."""
 
