@@ -2073,3 +2073,53 @@ class TestTableFunctions(PyfitsTestCase):
             assert_equal(h[1].header['NAXIS2'], 0)
             assert_true(isinstance(h[1].data, pyfits.FITS_rec))
             assert_equal(len(h[1].data), 0)
+
+    def test_copy_vla(self):
+        """
+        Regression test for https://github.com/spacetelescope/PyFITS/issues/47
+        """
+
+        # Make a file containing a couple of VLA tables
+        arr1 = [np.arange(n + 1) for n in xrange(255)]
+        arr2 = [np.arange(255, 256 + n) for n in xrange(255)]
+
+        # A dummy non-VLA column needed to reproduce issue #47
+        c = pyfits.Column('test', format='J', array=np.arange(255))
+        c1 = pyfits.Column('A', format='PJ', array=arr1)
+        c2 = pyfits.Column('B', format='PJ', array=arr2)
+        t1 = pyfits.new_table([c, c1])
+        t2 = pyfits.new_table([c, c2])
+
+        hdul = pyfits.HDUList([pyfits.PrimaryHDU(), t1, t2])
+        hdul.writeto(self.temp('test.fits'), clobber=True)
+
+        # Just test that the test file wrote out correctly
+        with pyfits.open(self.temp('test.fits')) as h:
+            assert h[1].header['TFORM2'] == 'PJ(255)'
+            assert h[2].header['TFORM2'] == 'PJ(255)'
+            assert comparerecords(h[1].data, t1.data)
+            assert comparerecords(h[2].data, t2.data)
+
+        # Try copying the second VLA and writing to a new file
+        with pyfits.open(self.temp('test.fits')) as h:
+            new_hdu = pyfits.BinTableHDU(data=h[2].data, header=h[2].header)
+            new_hdu.writeto(self.temp('test3.fits'))
+
+        with pyfits.open(self.temp('test3.fits')) as h2:
+            assert comparerecords(h2[1].data, t2.data)
+
+        new_hdul = pyfits.HDUList([pyfits.PrimaryHDU()])
+        new_hdul.writeto(self.temp('test2.fits'))
+
+        # Open several copies of the test file and append copies of the second
+        # VLA table
+        with pyfits.open(self.temp('test2.fits'), mode='append') as new_hdul:
+            for _ in range(2):
+                with pyfits.open(self.temp('test.fits')) as h:
+                    new_hdul.append(h[2])
+                    new_hdul.flush()
+
+        # Test that all the VLA copies wrote correctly
+        with pyfits.open(self.temp('test2.fits')) as new_hdul:
+            for idx in range(1, 3):
+                assert comparerecords(new_hdul[idx].data, t2.data)
